@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # Common Carla code
-# Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
+# Copyright (C) 2011-2023 Filipe Coelho <falktx@falktx.com>
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as
@@ -71,7 +71,7 @@ if WINDOWS:
 # ------------------------------------------------------------------------------------------------------------
 # Set Version
 
-VERSION = "2.5.1"
+VERSION = "2.5.3"
 
 # ------------------------------------------------------------------------------------------------------------
 # Set TMP
@@ -296,10 +296,12 @@ CARLA_DEFAULT_AUDIO_BUFFER_SIZE     = 512
 CARLA_DEFAULT_AUDIO_SAMPLE_RATE     = 44100
 CARLA_DEFAULT_AUDIO_TRIPLE_BUFFER   = False
 
-if WINDOWS:
-    CARLA_DEFAULT_AUDIO_DRIVER = "Windows Audio"
+if HAIKU:
+    CARLA_DEFAULT_AUDIO_DRIVER = "SDL"
 elif MACOS:
     CARLA_DEFAULT_AUDIO_DRIVER = "CoreAudio"
+elif WINDOWS:
+    CARLA_DEFAULT_AUDIO_DRIVER = "Windows Audio"
 elif os.path.exists("/usr/bin/jackd") or os.path.exists("/usr/bin/jackdbus") or os.path.exists("/usr/bin/pw-jack"):
     CARLA_DEFAULT_AUDIO_DRIVER = "JACK"
 else:
